@@ -167,22 +167,6 @@ def hook_local_call(bridge_conn, target_callable, *args, **kwargs):
 
     # Possible future - pull an execute sync flag kwarg from the callable args, to allow explicitly marking a particular call as MFF_READ or not needing execute sync
 
-    # if python2, make sure any arguments and keywords that are unicode are converted to plain strings
-    if sys.version_info.major == 2:
-        new_args = []
-        for arg in args:
-            if isinstance(arg, unicode):
-                arg = str(arg)
-            new_args.append(arg)
-        args = new_args
-
-        new_kwargs = {}
-        for k, v in kwargs.items():
-            if isinstance(v, unicode):
-                v = str(v)
-            new_kwargs[k] = v
-        kwargs = new_kwargs
-
     # bind the target to the arguments
     prepped_function = functools.partial(target_callable, *args, **kwargs)
 
@@ -200,11 +184,17 @@ def hook_local_eval(bridge_conn, eval_expr, eval_globals, eval_locals):
     return call_execute_sync_and_get_result(prepped_function)
 
 
+def exec_wrapper(exec_expr, exec_globals=None, exec_locals=None):
+    """ Wrap exec, to provide backcompat for python2, where it's not a function and so can't be bound
+        with functools.partial """
+    exec(exec_expr, exec_globals, exec_locals)
+
+
 def hook_local_exec(bridge_conn, exec_expr, exec_globals):
     """ Hook the real local_exec and use execute_sync to run the exec on the main thread """
 
     # first, bind the exec function to the arguments
-    prepped_function = functools.partial(exec, exec_expr, exec_globals)
+    prepped_function = functools.partial(exec_wrapper, exec_expr, exec_globals)
 
     return call_execute_sync_and_get_result(prepped_function)
 
